#
# spec file for package jettison
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jettison
Version:        1.5.4
Release:        2.7
Summary:        A JSON StAX implementation
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://jettison.codehaus.org/
Source0:        https://github.com/jettison-json/%{name}/archive/refs/tags/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildArch:      noarch

%description
Jettison is a collection of Java APIs (like STaX and DOM) which read
and write JSON. This allows nearly transparent enablement of JSON based
web services in services frameworks like CXF or XML serialization
frameworks like XStream.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Tue Sep  5 2023 Fridrich Strba <fstrba@suse.com>
- Make manifest timestamp reproducible
* Tue Apr 18 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.5.4
  * Fixes:
    + Fixing issue 60: Infinite recursion triggered when
    constructing a JSONArray from a Collection (bsc#1209605,
    CVE-2023-1436)
* Wed Dec 14 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.5.3
  * Fixes:
    + Backslash escaping. Throw syntax exception on invalid json
    sooner
    + Adding another test for backslashes
    + Introducing new static methods to set the recursion depth
    limit
    + Incorrect recursion depth check in JSONTokener
    + Fixing StackOverflow error (bsc#1206400, CVE-2022-45685,
    bsc#1206401, CVE-2022-45693)
* Wed Oct  5 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.5.1
  * Fixes:
    + Stack Overflow fix on malformed JSON
    (bsc#1203515, CVE-2022-40149)
    + Prevent infinite loop when a /* comment is not terminated
    (bsc#1203516, CVE-2022-40150)
- Removed patches:
  * jettison-1.3.7-jdk10plus.patch
  * jettison-update-woodstox-version.patch
    + not needed with current version
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Tue Jun  4 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jettison 1.3.7
